@@ -3,7 +3,7 @@ package Sort::Sub;
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
 our $DATE = '2019-12-15'; # DATE
 our $DIST = 'Sort-Sub'; # DIST
-our $VERSION = '0.114'; # VERSION
+our $VERSION = '0.115'; # VERSION
 
 use 5.010001;
 use strict 'subs', 'vars';
@@ -77,7 +77,7 @@ Sort::Sub - Collection of sort subroutines
 
 =head1 VERSION
 
-This document describes version 0.114 of Sort::Sub (from Perl distribution Sort-Sub), released on 2019-12-15.
+This document describes version 0.115 of Sort::Sub (from Perl distribution Sort-Sub), released on 2019-12-15.
 
 =head1 SYNOPSIS
 
@@ -204,6 +204,13 @@ When submitting a bug or request, please include a test-file or a
 patch to an existing test-file that illustrates the bug or desired
 feature.
 
+=head1 SEE ALSO
+
+Other additional C<Sort::Sub::*> not bundled in this distribution.
+
+Supporting CLI's: L<sortsub> (from L<App::sortsub>), CLI's from
+L<App::SortSubUtils>.
+
 =head1 AUTHOR
 
 perlancar <perlancar@cpan.org>
